RustyLink

Struct RustyLink 

pub struct RustyLink { /* private fields */ }

Implementations

pub fn connect(vendor_id: u16, product_id: u16) -> Result<RustyLink, RlnError>

pub fn default_mode(&mut self) -> Result<(), RlnError>

Sets the board in default mode, which is the mode the board starts in. In this mode, the FEN is not read, but you can still interact with the board

pub fn real_time_mode(&mut self) -> Result<(), RlnError>

Sets the board to real-time mode. In this mode, the FEN is continuously read. Please note that this does not implement debouncing, therefore sliding a piece on the board will successively register all positions the piece passes through.

pub fn fen(&self) -> String

Returns the last FEN string registered by the board, if any. An empty string will be returned if the board was never put in real-time mode before.

pub fn battery_state(&self) -> u8

Returns the battery state, in percentage.

pub fn update_led(&mut self, led_state: [u8; 8]) -> Result<(), RlnError>

Update LEDs state, with each u8 representing a row and beginning with the H row.

pub fn led(&self) -> [u8; 8]

Returns the LEDs state.

pub fn beep(&mut self, frequency: u16, duration: u16) -> Result<(), RlnError>

beeps with a specified frequency (in Hz) and duration (in ms) Can be used to make music !?